Module: Jekyll::Brotli
- Defined in:
- lib/jekyll/brotli/compressor.rb,
lib/jekyll/brotli.rb,
lib/jekyll/brotli/config.rb,
lib/jekyll/brotli/version.rb
Overview
The main namespace for Jekyll::Brotli. Includes the Compressor module
which is used to map over files, either using an instance of Jekyll::Site
or a directory path, and compress them using Brotli.
Defined Under Namespace
Modules: Compressor
Constant Summary collapse
- DEFAULT_CONFIG =
{ 'quality' => 11, 'extensions' => [ '.html', '.css', '.js', '.json', '.txt', '.ttf', '.atom', '.stl', '.xml', '.svg', '.eot' ].freeze }.freeze
- VERSION =
"2.4.1"